<?php

/*
 * This file is part of the Comptoir-du-Libre software.
 * <https://gitlab.adullact.net/Comptoir/comptoir-du-libre>
 *
 * Copyright (c) ADULLACT   <https://adullact.org>
 *               Association des Développeurs et Utilisateurs de Logiciels Libres
 *               pour les Administrations et les Collectivités Territoriales
 *
 * Comptoir-du-Libre is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this software. If not, see <https://www.gnu.org/licenses/agpl-3.0.en.html>.
 */

declare(strict_types=1);

namespace App\DataFixtures;

use App\Entity\Organization;
use App\Entity\OrganizationI18n;
use App\Entity\OrganizationType;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Persistence\ObjectManager;

class AppOrganizationFixtures extends Fixture
{
    public const ORGANIZATION_TYPES = [
        'public_sector', 'no_profit', 'company'
    ];

    public const ORGANIZATIONS = [
        1 => [
            'id' => 1, // must be identical to array key
            'createdAt' => '2016-06-19 13:31:24',
            'updatedAt' => '2025-01-25 14:22:05',
            'type' => 'no_profit',
            'name' => "ADULLACT",
            'slug' => 'adullact',
            'website' => 'https://adullact.org',
            'oldComptoirId' => 999,
            'description' => [
                'fr' => "Association **des** ...\n"
                        . "- logiciel libre\n- numrérique libre",
                'en' => 'No **profit** organization...',
            ],
        ],
        2 => [
            'id' => 2,  // must be identical to array key
            'createdAt' => '2022-06-19 13:31:24',
            'updatedAt' => '2022-07-25 14:22:05',
            'type' => 'public_sector',
            'name' => "Mairie d'Abbeville",
            'slug' => 'mairie-d-abbeville',
        ],
        3 => [
            'id' => 3, // must be identical to array key
            'createdAt' => '2023-06-19 13:31:24',
            'updatedAt' => '2023-07-25 14:22:05',
            'type' => 'public_sector',
            'name' => "Ville Montpellier (34)",
            'slug' => 'ville-montpellier-34',
            'website' => 'https://www.montpellier.fr',
            'oldComptoirId' => 17,
        ],
    ];


    public function load(ObjectManager $manager): void
    {
        $organizationTypes = [];
        foreach (self::ORGANIZATION_TYPES as $type) {
            $organizationType = new OrganizationType();
            $organizationType->setName("$type");
            $manager->persist($organizationType);
            $manager->flush();
            $organizationTypes["$type"] = $organizationType;
        }

        foreach (self::ORGANIZATIONS as $key => $data) {
            $createdAt = new \DateTimeImmutable($data['createdAt']);
            $updatedAt = new \DateTimeImmutable($data['updatedAt']);
            $organization = new Organization();
            $organization->setName($data['name']);
            $organization->setSlug($data['slug']);
            $organization->setCreatedAt($createdAt);
            $organization->setUpdatedAt($updatedAt);
            $organization->setType($organizationTypes[$data['type']]);
            if (isset($data['website'])) {
                $organization->setWebsite($data['website']);
            }
            if (isset($data['oldComptoirId'])) {
                $organization->setOldComptoirId($data['oldComptoirId']);
            }
            $manager->persist($organization);
            $manager->flush();

            if (isset($data['description'])) {
                foreach ($data['description'] as $locale => $text) {
                    $organizationI18n = new OrganizationI18n();
                    $organizationI18n->setOrganization($organization);
                    $organizationI18n->setLocale($locale);
                    $organizationI18n->setType(1);
                    $organizationI18n->setText($text);
                    $manager->persist($organizationI18n);
                    $manager->flush();
                }
            }
        }
    }
}
